@@ -148,6 +148,13 @@ class MissingInfo(Exception):
         super(MissingInfo, self).__init__(msg)
 
 
+class GenericObjectMissingLoadMasterInfo(MissingInfo):
+    def __init__(self, service, param):
+        self.service = service
+        self.param_name = "LoadMaster"
+        super(GenericObjectMissingLoadMasterInfo, self).__init__(param)
+
+
 class VirtualServiceMissingLoadmasterInfo(MissingInfo):
     service = 'Virtual service'
     param_name = 'LoadMaster'
@@ -190,3 +197,59 @@ class NotVirtualServiceInstanceError(KempTechApiException):
         msg = ("The object you are trying to clone is "
                "not an instance of VirtualService.")
         super(NotVirtualServiceInstanceError, self).__init__(msg, code=code)
+
+
+class AccessControlMissingLoadmasterInfo(MissingInfo):
+    service = 'Access Control'
+    param_name = 'LoadMaster'
+
+
+class AccessControlMissingVirtualServiceInfo(MissingInfo):
+    service = 'Access Control'
+    param_name = 'Virtual service'
+
+
+class TemplateMissingLoadmasterInfo(MissingInfo):
+    service = 'Template'
+    param_name = 'LoadMaster'
+
+
+class CertificateMissingLoadmasterInfo(MissingInfo):
+    service = 'Certificate'
+    param_name = 'LoadMaster'
+
+
+class RuleMissingLoadmasterInfo(MissingInfo):
+    service = 'Rule'
+    param_name = 'LoadMaster'
+
+
+class FqdnMissingLoadmasterInfo(MissingInfo):
+    service = 'Fqdn'
+    param_name = 'LoadMaster'
+
+
+class SiteMissingFQDNInfo(MissingInfo):
+    service = 'Site'
+    param_name = 'FQDN'
+
+
+class SiteMissingLoadmasterInfo(MissingInfo):
+    service = 'Site'
+    param_name = 'LoadMaster'
+
+
+class ClusterMissingLoadmasterInfo(MissingInfo):
+    service = 'Cluster'
+    param_name = 'LoadMaster'
+
+
+class RangeMissingLoadmasterInfo(MissingInfo):
+    service = 'Range'
+    param_name = 'LoadMaster'
+
+
+class RangeMaskInvalid(ValidationError):
+    def __init__(self, mask):
+        msg = "Specified netmask is invalid. Mask must be between 8-32"
+        super(RangeMaskInvalid, self).__init__(msg)
