@@ -2,12 +2,16 @@ import requests
 from nose.tools import (assert_equal, assert_is_instance, assert_raises,
    assert_false, assert_in)
 
+import python_kemptech_api.generic
+import python_kemptech_api.models
+import python_kemptech_api.objects
 from python_kemptech_api import api_xml
+from python_kemptech_api import generic
 
 try:
     import unittest.mock as mock
 except ImportError:
-    import  mock
+    import mock
 
 mock_open = mock.mock_open
 patch = mock.patch
@@ -20,7 +24,7 @@ from requests import exceptions
 import python_kemptech_api.client as client
 from python_kemptech_api import utils
 
-LoadMaster = client.LoadMaster
+LoadMaster = python_kemptech_api.models.LoadMaster
 
 class MyError(Exception):
     pass
@@ -29,21 +33,21 @@ class MyError(Exception):
 class Test_HttpClient_as_context_manager:
 
     def test_context_manager_enter(self):
-        with client.HttpClient() as aclient:
-            assert_is_instance(aclient, client.HttpClient)
+        with python_kemptech_api.generic.HttpClient() as aclient:
+            assert_is_instance(aclient, python_kemptech_api.generic.HttpClient)
 
     def test_context_manager_exit(self):
         with assert_raises(MyError):
-            with client.HttpClient():
+            with python_kemptech_api.generic.HttpClient():
                 raise MyError('An Error')
 
 
 class Test_HttpClient_do_request:
 
     def setup(self):
-        self.p_Session = patch.object(client, 'Session')
+        self.p_Session = patch.object(generic, 'Session')
         Session = self.p_Session.start()
-        self.p_requests = patch.object(client, 'requests')
+        self.p_requests = patch.object(generic, 'requests')
         rquests = self.p_requests.start()
         Session.return_value = rquests
 
@@ -53,7 +57,7 @@ class Test_HttpClient_do_request:
         self.request = rquests.request
         self.request.return_value = self.response
 
-        self.client = client.HttpClient()
+        self.client = python_kemptech_api.generic.HttpClient()
         self.client.endpoint = 'ep/'
 
     def teardown(self):
@@ -75,7 +79,7 @@ class Test_HttpClient_do_request:
 
     def test_file_parameter_set(self):
         open_ = mock_open(read_data='myData')
-        with patch.object(client, "open", open_, create=True): # as my_open:
+        with patch.object(generic, "open", open_, create=True): # as my_open:
            self.client._do_request('GET','MyCommand',
                                                 parameters=sentinel.params,
                                                 file='my_filename')
@@ -136,7 +140,7 @@ class Test_HttpClient_do_request:
 class Test_LoadMaster:
 
     def test_build_virtual_server(self):
-        lm = client.LoadMaster('ip','username','password')
+        lm = python_kemptech_api.models.LoadMaster('ip', 'username', 'password')
         lm.ip_address = "1.1.1.1"
         with patch.object(LoadMaster,'endpoint', new_callable=PropertyMock) as mock_endpoint:
             mock_endpoint.return_value =  "https://bal:2fourall@1.1.1.1:443/access"
@@ -167,7 +171,12 @@ class Test_LoadMaster:
 class Test_KempBaseObjectModel:
 
     def test_to_api_dict(self):
-        kbom = client.KempBaseObjectModel()
+        loadmaster_access = {
+            "endpoint": "https://bal:1fourall@1.1.1.1:443/access",
+            "ip_address": "1.1.1.1",
+        }
+
+        kbom = python_kemptech_api.generic.BaseKempObject(loadmaster_access)
         kbom.none = None
         kbom.real_one = 'real'
         kbom._underscore = 'not wanted'
