@@ -12,9 +12,9 @@ except ImportError:
 patch = mock.patch
 sentinel = mock.sentinel
 
+from python_kemptech_api import objects
 import python_kemptech_api.exceptions as exceptions
-import python_kemptech_api.client as client
-from python_kemptech_api.client import VirtualService, RealServer
+from python_kemptech_api.objects import VirtualService, RealServer
 
 ValidationError = exceptions.ValidationError
 
@@ -95,21 +95,37 @@ class Test_get_real_servers:
 
     def test_data_exists(self):
         with patch.object(VirtualService, 'build_real_server') as build_real_server:
-            with patch.object(client, 'get_data') as get_data:
+            with patch.object(objects, 'get_data') as get_data:
                 with patch.object(VirtualService, '_get'):
                     build_real_server.side_effect = sorted
                     get_data. return_value = {'Rs': ['ba', 'ed']}
                     res =  self.vs.get_real_servers()
         expected = [['a','b'], ['d','e']]
         assert_equal(res, expected)
+        """
+        rs1 = [x for x in res if x.rs == "1.1.2.1"].pop()
+        rs2 = [x for x in res if x.rs == "1.1.2.2"].pop()
+
+        assert_equal(rs1.vs, "1.1.1.2")
+        assert_equal(rs2.vs, "1.1.1.2")
+
+        assert_equal(rs1.port, 80)
+        assert_equal(rs2.port, 80)
+
+        assert_equal(rs1.rs, "1.1.2.1")
+        assert_equal(rs2.rs, "1.1.2.2")
+
+        assert_equal(rs1.rsport, 80)
+        assert_equal(rs2.rsport, 8080)
+        """
 
     def test_no_data_exists(self):
         with patch.object(VirtualService, 'build_real_server') as build_real_server:
-            with patch.object(client, 'get_data') as get_data:
+            with patch.object(objects, 'get_data') as get_data:
                 with patch.object(VirtualService, '_get'):
                     build_real_server.side_effect = sorted
-                    get_data. return_value = {}
-                    res =  self.vs.get_real_servers()
+                    get_data.return_value = {}
+                    res = self.vs.get_real_servers()
         expected = []
         assert_equal(res, expected)
 
@@ -125,16 +141,29 @@ class Test_get_real_server:
 
     def test_with_index_ok(self):
         with patch.object(VirtualService, 'build_real_server') as build_real_server:
-            with patch.object(client, 'get_data'):
+            with patch.object(objects, 'get_data'):
                 with patch.object(VirtualService, '_get'):
                     self.vs.index = self
                     build_real_server.return_value = sentinel.rs
                     res =  self.vs.get_real_server('1.1.1.1', 80)
         assert_equal(res, sentinel.rs)
+        """
+        with patch.object(VirtualService, 'build_real_server') as build_real_server:
+            with patch.object(objects, 'get_data') as get_data:
+                with patch.object(VirtualService, '_get'):
+                    self.vs.index = self
+                    get_data.return_value = {
+                        "Rs": {"Addr": "1.1.1.1", "Port": 80}
+                    }
+                    res = self.vs.get_real_server('1.1.1.1', 80)
+
+        assert_equal(res.rs, "1.1.1.1")
+        assert_equal(res.rsport, 80)
+        """
 
     def test_with_index_invalid_ip(self):
         with patch.object(VirtualService, 'build_real_server') as build_real_server:
-            with patch.object(client, 'get_data'):
+            with patch.object(objects, 'get_data'):
                 with patch.object(VirtualService, '_get'):
                     self.vs.index = self
                     build_real_server.return_value = sentinel.rs
@@ -143,7 +172,7 @@ class Test_get_real_server:
 
     def test_with_index_invalid_port(self):
         with patch.object(VirtualService, 'build_real_server') as build_real_server:
-            with patch.object(client, 'get_data'):
+            with patch.object(objects, 'get_data'):
                 with patch.object(VirtualService, '_get'):
                     self.vs.index = self
                     build_real_server.return_value = sentinel.rs
@@ -152,16 +181,29 @@ class Test_get_real_server:
 
     def test_without_index_ok(self):
         with patch.object(VirtualService, 'build_real_server') as build_real_server:
-            with patch.object(client, 'get_data'):
+            with patch.object(objects, 'get_data'):
                 with patch.object(VirtualService, '_get'):
                     self.vs.index = None
                     build_real_server.return_value = sentinel.rs
                     res =  self.vs.get_real_server('1.1.1.1', 80)
         assert_equal(res, sentinel.rs)
+        """
+        with patch.object(VirtualService, 'build_real_server'):
+            with patch.object(objects, 'get_data') as get_data:
+                with patch.object(VirtualService, '_get'):
+                    self.vs.index = None
+                    get_data.return_value = {
+                        "Rs": {"Addr": "1.1.1.1", "Port": 80}
+                    }
+                    res = self.vs.get_real_server('1.1.1.1', 80)
+
+        assert_equal(res.rs, "1.1.1.1")
+        assert_equal(res.rsport, 80)
+        """
 
     def test_without_index_invalid_ip(self):
         with patch.object(VirtualService, 'build_real_server') as build_real_server:
-            with patch.object(client, 'get_data'):
+            with patch.object(objects, 'get_data'):
                 with patch.object(VirtualService, '_get'):
                     self.vs.index = None
                     build_real_server.return_value = sentinel.rs
@@ -170,12 +212,12 @@ class Test_get_real_server:
 
     def test_without_index_invalid_port(self):
         with patch.object(VirtualService, 'build_real_server') as build_real_server:
-            with patch.object(client, 'get_data'):
+            with patch.object(objects, 'get_data'):
                 with patch.object(VirtualService, '_get'):
                     self.vs.index = None
                     build_real_server.return_value = sentinel.rs
                     with assert_raises(ValidationError):
-                        self.vs.get_real_server('1.1.1.1., junk')
+                        self.vs.get_real_server('1.1.1.1.', 'junk')
 
 
 class Test_build_real_server:
